(developer.data_access)=
# Data Access
This section provides information on how to access data in BEC. It is recommended to first read the [architecture section](developer.architecture) before getting started with the introduction to the messaging system in BEC. This will help you to understand the general concepts of the event based system in BEC.

```{toctree}
---
maxdepth: 2
hidden: true
---
bec_messaging/
event_data/
```
